
#include <QString>

QString EscapeXmlDump( const QString& strIn );
